import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as Storyname from "./tus-form.stories";

<Meta of={Storyname} name="Docs" />

# TUS Form

## Technical Data

It contains the form with the technical details.
When this form is submitted, the backand should save the submitted information about the
part that the user wants to return. <br />

### Possible user actions

-   The user selects a reason for the return and clicks save. This will submit the form to the specified
    url in the form action attribute.

<Canvas of={Storyname.TechnicalData}></Canvas>

## Overview

It contains a list of all parts that the user has submitted. <br />
The information about the submitted data from the user is shown in the form of thumbnails.
The HTML structure of the thumbnail is described in the source code of this story. <br />

### Possible user actions

-   The user clicks on the button "Add another part": this should be a link that takes the user to
    a page like the one detailed in the story named "Add additional part".
-   The user clicks on the button "Go to the next step": this should be a link that takes the user
    to a page like the one detailed in the story named "Contact details".
-   The user clicks on the delete icon for a particular part: this opens a modal that asks the user for
    confirmation that they want to delete the part.
-   The user clicks on the edit icon for a particular part: this should be a link that takes the user to
    a page like the one described in the word.

<Canvas of={Storyname.Overview}></Canvas>

# Add additional part

Template that allows the user to add an additional part. <br />
It contains the thumbnail overview for the parts that the user has already submitted,
and includes the form that allows the user to submit a new part. <br />
This form differs from the initial form (Technical Details step) in that the following element with links
should be included:

```
<div
    class="ux-iws-tus-form__controls"
    data-ux-static-filter="return="
>
    <a
        class="ux-button"
        href="./iframe.html?id=trumpf-com-modules-tus-return-form--overview#tus-form"
    >
        Cancel
    </a>
    <a
        class="ux-button ux-button--green"
        href="./iframe.html?id=trumpf-com-modules-tus-return-form--contact-details#tus-form"
    >
        Cancel and go to the next step
    </a>
</div>
```

These links allow the user to cancel the submission of another part by simply linking back to the
overview page ("Cancel") or linking to the Contact details page ("Cancel and go to the next step"). <b/>
By having the attribute `data-ux-static-filter="return="` on the wrapper of these links, we ensure that
these are only shown when the user has not already selected any reason for the return.

<Canvas of={Storyname.AddAdditionalPart}></Canvas>

# Edit part

This template allows the user to edit the details for a part that he has already submitted. <br />
It contains the thumbnail overview for the parts that the user has already submitted,
plus the form for the part that the user would like to edit, with the form fields
containing the details that the user has already submitted previously.

<Canvas of={Storyname.EditPart}></Canvas>

# Contact Details

This template contains the form for the contact details of the user. <br />
It contains the thumbnail overview for the parts that the user has already submitted,
plus the form with the contact details.

<Canvas of={Storyname.ContactDetails}></Canvas>

# Success Page

The success page of the TUS form. <br />
It contains a success message and it contains an overview of the parts that have been submitted,
with an additional download button that allows the user to download the PDF with the overview.

<Canvas of={Storyname.SuccessPage}></Canvas>

# Backend error technical detail

If the backend validation fails, e.i., there is an field that contains invalid data,
any form element of the core library (elements that start with `ux-`) can be given
the `error` and `error-message="Any error message"` attributes. <br />
This will show the user that there is an error in the form. <br />
Just send the page back with the input fields that contain the error with the above-mentioned
attributes. <br />
The same principles can be applied to the contact form step.

<Canvas of={Storyname.BackendErrorTechnicalDetail}></Canvas>
